Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
index 147ff1b36b66d30a55ea39a1fbcc8552e65b3f49..befc619cb17285b90b5d8282ea64b3b2e241f177 100644 |
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
@@ -118,9 +118,9 @@ class ParsedRtcEventLog { |
// Only the fields that are stored in the protobuf will be written. |
void GetVideoReceiveConfig(size_t index, rtclog::StreamConfig* config) const; |
// Reads a config event to a (non-NULL) VideoSendStream::Config struct. |
// Only the fields that are stored in the protobuf will be written. |
- void GetVideoSendConfig(size_t index, VideoSendStream::Config* config) const; |
+ void GetVideoSendConfig(size_t index, rtclog::StreamConfig* config) const; |
// Reads a config event to a (non-NULL) AudioReceiveStream::Config struct. |
// Only the fields that are stored in the protobuf will be written. |
@@ -118,9 +118,9 @@ class ParsedRtcEventLog { |
// Only the fields that are stored in the protobuf will be written. |
void GetVideoReceiveConfig(size_t index, rtclog::StreamConfig* config) const; |
- // Reads a config event to a (non-NULL) VideoSendStream::Config struct. |
+ // Reads a config event to a (non-NULL) StreamConfig struct. |
// Only the fields that are stored in the protobuf will be written. |